@@ -1,4 +1,9 @@
-"""Docker utilities for HUD CLI."""
+"""Docker utilities for HUD CLI.
+
+This module centralizes helpers for constructing Docker commands and
+standardizes environment variable handling for "folder mode" (environment
+directories that include a `.env` file and/or `hud.lock.yaml`).
+"""
 
 from __future__ import annotations
 
@@ -6,6 +11,12 @@ import json
 import platform
 import shutil
 import subprocess
+from pathlib import Path
+
+from .config import parse_env_file
+
+# Note: we deliberately avoid the stricter is_environment_directory() check here
+# to allow folder mode with only a Dockerfile or only a pyproject.toml.
 
 
 def get_docker_cmd(image: str) -> list[str] | None:
@@ -36,45 +47,6 @@ def get_docker_cmd(image: str) -> list[str] | None:
         return None
 
 
-def inject_supervisor(cmd: list[str]) -> list[str]:
-    """
-    Inject watchfiles CLI supervisor into a Docker CMD.
-
-    For shell commands, we inject before the last exec command.
-    For direct commands, we wrap the entire command.
-
-    Args:
-        cmd: Original Docker CMD
-
-    Returns:
-        Modified CMD with watchfiles supervisor injected
-    """
-    if not cmd:
-        return cmd
-
-    # Handle shell commands that might have background processes
-    if cmd[0] in ["sh", "bash"] and len(cmd) >= 3 and cmd[1] == "-c":
-        shell_cmd = cmd[2]
-
-        # Look for 'exec' in the shell command - this is the last command
-        if " exec " in shell_cmd:
-            # Replace only the exec'd command with watchfiles
-            parts = shell_cmd.rsplit(" exec ", 1)
-            if len(parts) == 2:
-                # Extract the actual command after exec
-                last_cmd = parts[1].strip()
-                # Use watchfiles with logs redirected to stderr (which won't interfere with MCP on stdout)  # noqa: E501
-                new_shell_cmd = f"{parts[0]} exec watchfiles --verbose '{last_cmd}' /app/src"
-                return [cmd[0], cmd[1], new_shell_cmd]
-        else:
-            # No exec, the whole thing is the command
-            return ["sh", "-c", f"watchfiles --verbose '{shell_cmd}' /app/src"]
-
-    # Direct command - wrap with watchfiles
-    watchfiles_cmd = " ".join(cmd)
-    return ["sh", "-c", f"watchfiles --verbose '{watchfiles_cmd}' /app/src"]
-
-
 def image_exists(image_name: str) -> bool:
     """Check if a Docker image exists locally."""
     result = subprocess.run(  # noqa: S603
@@ -121,6 +93,135 @@ def generate_container_name(identifier: str, prefix: str = "hud") -> str:
     return f"{prefix}-{safe_name}"
 
 
+def build_run_command(image: str, docker_args: list[str] | None = None) -> list[str]:
+    """Construct a standard docker run command used across CLI commands.
+
+    Args:
+        image: Docker image name to run
+        docker_args: Additional docker args to pass before the image
+
+    Returns:
+        The docker run command list
+    """
+    args = docker_args or []
+    return [
+        "docker",
+        "run",
+        "--rm",
+        "-i",
+        *args,
+        image,
+    ]
+
+
+def detect_environment_dir(start_dir: Path | None = None) -> Path | None:
+    """Detect an environment directory for folder mode.
+
+    Detection order:
+    - Current directory containing `hud.lock.yaml`
+    - Parent directory containing `hud.lock.yaml`
+    - Current directory that looks like an environment if it has either a
+      `Dockerfile` or a `pyproject.toml` (looser than `is_environment_directory`).
+
+    Returns the detected directory path or None if not found.
+    """
+    base = (start_dir or Path.cwd()).resolve()
+
+    # Check current then parent for lock file
+    for candidate in [base, base.parent]:
+        if (candidate / "hud.lock.yaml").exists():
+            return candidate
+
+    # Fallback: treat as env if it has Dockerfile OR pyproject.toml
+    if (base / "Dockerfile").exists() or (base / "pyproject.toml").exists():
+        return base
+
+    return None
+
+
+def load_env_vars_for_dir(env_dir: Path) -> dict[str, str]:
+    """Load KEY=VALUE pairs from `<env_dir>/.env` if present.
+
+    Returns an empty dict if no file is found or parsing fails.
+    """
+    env_file = env_dir / ".env"
+    if not env_file.exists():
+        return {}
+    try:
+        contents = env_file.read_text(encoding="utf-8")
+        return parse_env_file(contents)
+    except Exception:
+        return {}
+
+
+def build_env_flags(env_vars: dict[str, str]) -> list[str]:
+    """Convert an env dict into a flat list of `-e KEY=VALUE` flags."""
+    flags: list[str] = []
+    for key, value in env_vars.items():
+        flags.extend(["-e", f"{key}={value}"])
+    return flags
+
+
+def create_docker_run_command(
+    image: str,
+    docker_args: list[str] | None = None,
+    env_dir: Path | str | None = None,
+    extra_env: dict[str, str] | None = None,
+    name: str | None = None,
+    interactive: bool = True,
+    remove: bool = True,
+) -> list[str]:
+    """Create a standardized `docker run` command with folder-mode envs.
+
+    - If `env_dir` is provided (or auto-detected), `.env` entries are injected as
+      `-e KEY=VALUE` flags before the image.
+    - `extra_env` allows callers to provide additional env pairs that override
+      variables from `.env`.
+
+    Args:
+        image: Docker image to run
+        docker_args: Additional docker args (volumes, ports, etc.)
+        env_dir: Environment directory to load `.env` from; if None, auto-detect
+        extra_env: Additional env variables to inject (takes precedence)
+        name: Optional container name
+        interactive: Include `-i` flag (default True)
+        remove: Include `--rm` flag (default True)
+
+    Returns:
+        Fully constructed docker run command
+    """
+    cmd: list[str] = ["docker", "run"]
+    if remove:
+        cmd.append("--rm")
+    if interactive:
+        cmd.append("-i")
+    if name:
+        cmd.extend(["--name", name])
+
+    # Load env from `.env` in detected env directory
+    env_dir_path: Path | None = (
+        Path(env_dir).resolve() if isinstance(env_dir, (str, Path)) else detect_environment_dir()
+    )
+
+    merged_env: dict[str, str] = {}
+    if env_dir_path is not None:
+        merged_env.update(load_env_vars_for_dir(env_dir_path))
+    if extra_env:
+        # Caller-provided values override .env
+        merged_env.update(extra_env)
+
+    # Insert env flags before other args
+    if merged_env:
+        cmd.extend(build_env_flags(merged_env))
+
+    # Add remaining args (volumes, ports, etc.)
+    if docker_args:
+        cmd.extend(docker_args)
+
+    cmd.append(image)
+    return cmd
+
+
 def _emit_docker_hints(error_text: str) -> None:
     """Parse common Docker connectivity errors and print platform-specific hints."""
     from hud.utils.hud_console import hud_console
