@@ -38,7 +38,7 @@ HUD_API_KEY_MISSING = Hint(
     message="Missing or invalid HUD_API_KEY.",
     tips=[
         "Set HUD_API_KEY in your environment or run: hud set HUD_API_KEY=your-key-here",
-        "Get a key at https://app.hud.so",
+        "Get a key at https://hud.so",
         "Check for whitespace or truncation",
     ],
     docs_url=None,
@@ -61,6 +61,31 @@ RATE_LIMIT_HIT = Hint(
     context=["network"],
 )
 
+# Billing / plan upgrade
+PRO_PLAN_REQUIRED = Hint(
+    title="Pro plan required",
+    message="This feature requires Pro.",
+    tips=[
+        "Upgrade your plan to continue",
+    ],
+    docs_url="https://hud.so/project/billing",
+    command_examples=None,
+    code="PRO_PLAN_REQUIRED",
+    context=["billing", "plan"],
+)
+
+CREDITS_EXHAUSTED = Hint(
+    title="Credits exhausted",
+    message="Your credits are exhausted.",
+    tips=[
+        "Top up credits or upgrade your plan",
+    ],
+    docs_url="https://hud.so/project/billing",
+    command_examples=None,
+    code="CREDITS_EXHAUSTED",
+    context=["billing", "credits"],
+)
+
 TOOL_NOT_FOUND = Hint(
     title="Tool not found",
     message="Requested tool doesn't exist.",
